==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
var WebDropdownItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDropdownItemDescriptionMetadata, _super);
    function WebDropdownItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownItemDescriptionMetadata.b = function (a) {
        if (WebDropdownItemDescriptionMetadata.a == null) {
            WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
        }
        if (a.g(WebDropdownItemDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDropdownItemDescriptionMetadata.a);
    };
    WebDropdownItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownItem");
        a.item("Value", "String");
        a.item("Selected", "Boolean");
        a.item("Active", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebDropdownItemDescriptionMetadata.d = function (a) {
        WebDropdownItemDescriptionMetadata.b(a);
        a.u("WebDropdownItem", function () { return new WebDropdownItemDescription(); });
        a.t("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
    };
    WebDropdownItemDescriptionMetadata.$t = markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
}(Base));
export { WebDropdownItemDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
var WebDropdownItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDropdownItemDescriptionMetadata, _super);
    function WebDropdownItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownItemDescriptionMetadata.b = function (a) {
        if (WebDropdownItemDescriptionMetadata.a == null) {
            WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
        }
        if (a.j(WebDropdownItemDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDropdownItemDescriptionMetadata.a);
    };
    WebDropdownItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownItem");
        a.item("__tagNameWC", "String:igc-dropdown-item");
        a.item("Value", "String");
        a.item("Selected", "Boolean");
        a.item("Active", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebDropdownItemDescriptionMetadata.d = function (a) {
        WebDropdownItemDescriptionMetadata.b(a);
        a.aa("WebDropdownItem", function () { return new WebDropdownItemDescription(); });
        a.z("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
    };
    WebDropdownItemDescriptionMetadata.$t = markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
}(Base));
export { WebDropdownItemDescriptionMetadata };
